@@ -138,9 +138,6 @@ class Inverter:
         """object identifier."""
         return f"{self.client}_{self._thing_serial}"
 
-    def check_connection(self) -> bool:
-        try:
-            self.realtime_data_request([])
-            return True
-        except (HttpRequestError, DeviceOfflineError):
-            return False
+    def check_connection(self) -> bool | None:
+        self.realtime_data_request([])
+        return True
